@@ -9,8 +9,7 @@ from geosoup.exceptions import *
 __all__ = ['Vector',
            'OGR_FIELD_DEF',
            'OGR_TYPE_DEF',
-           'OGR_GEOM_DEF',
-           'OGR_FIELD_DEF_INV']
+           'OGR_GEOM_DEF']
 
 
 OGR_FIELD_DEF = {
@@ -18,15 +17,14 @@ OGR_FIELD_DEF = {
     'integer': ogr.OFTInteger,
     'long': ogr.OFTInteger,
     'float': ogr.OFTReal,
+    'real': ogr.OFTReal,
     'double': ogr.OFTReal,
     'str': ogr.OFTString,
     'string': ogr.OFTString,
     'bool': ogr.OFTInteger,
     'nonetype': ogr.OFSTNone,
-    'none': ogr.OFSTNone
-}
+    'none': ogr.OFSTNone}
 
-OGR_FIELD_DEF_INV = dict(list((v, k) for k, v in OGR_FIELD_DEF.items()))
 
 OGR_TYPE_DEF = {
             'point': 1,
@@ -37,8 +35,8 @@ OGR_TYPE_DEF = {
             'multilinestring': 5,
             'multipolygon': 6,
             'geometry': 0,
-            'no geometry': 100
-}
+            'no geometry': 100}
+
 
 OGR_GEOM_DEF = {
                 1: 'point',
@@ -48,8 +46,7 @@ OGR_GEOM_DEF = {
                 5: 'multilinestring',
                 6: 'multipolygon',
                 0: 'geometry',
-                100: 'no geometry',
-}
+                100: 'no geometry',}
 
 
 class Vector(object):
@@ -117,7 +114,7 @@ class Vector(object):
         self.nfeat = 0
         self.fields = list()
         self.data = dict()
-        self.attr_def = attr_def
+        self.attr_def = attr_def if attr_def is not None else dict()
         self.bounds = None
 
         self.mode = 'read' if not append else 'write'
@@ -174,7 +171,11 @@ class Vector(object):
 
             # get field defintions
             layer_definition = self.layer.GetLayerDefn()
-            self.fields = [layer_definition.GetFieldDefn(i) for i in range(0, layer_definition.GetFieldCount())]
+            self.fields = [layer_definition.GetFieldDefn(i)
+                           for i in range(0, layer_definition.GetFieldCount())]
+
+            self.attr_def = {field.GetName(): field.GetTypeName().lower()
+                             for field in self.fields}
 
             if not append:
 
